grenswaarden = {    
    # Test 	Unit	Drempel_onder	Grens_onder	Drempel_boven	Grens_boven	Lambda function						
    "Temperatuur":	["C",	None,	None,	25,	25, 	lambda sol: sol.temperature],
    "Zuurstof":	["mg/l",	4,	2,	None,	None,	lambda sol: sol.molality('O2') * 32e3],
    "pH":	["pH",	7.7,	7,	8.3,	9.5,	lambda sol: sol.pH],
    "AgCO2":	["mg/l",	None,	None,	2.2,	2.2,	lambda sol: sol.aggco2 * 44],
    "EGV":	["mS/m",	None,	None,	80,	125,	lambda sol: sol.sc * 0.1],
    "HCO3":	["mg/l",	90,	60,	None,	None,	lambda sol: sol.total('HCO3') * 61e3],
    "Cl":	["mg/l",	None,	None,	100,	150,	lambda sol: sol.total('Cl') * 35.5e3],
    "SO4":	["mg SO4 / l",	None,	None,	100,	150,	lambda sol: sol.total('SO4') * 96.1e3],
    "NH4":	["mg NH4 / l",	None,	None,	0.05,	0.2,	lambda sol: sol.total('NH4') * 18e3],
    "NO2":	["mg NO2 / l",	None,	None,	0.03,	0.05,	lambda sol: sol.total('NO2') * 46e3],
    "NO3":	["mg NO3 / l",	None,	None,	25,	50,	lambda sol: sol.total('NO3') * 63e3],
    "CN":	["ug/l",	None,	None,	10,	50,	lambda sol: sol.total('CN') * 26e6],
    "F":	["mg/l",	None,	None,	1,	1,	lambda sol: sol.total_element('F') * 19e3],
    "TAC":	["mg/l",	24,	24,	None,	None,	lambda sol: sol.total('CO2') * 44e3 + sol.total('HCO3') * 61e3 + sol.total('CO3') * 60e3],
    "TACC90":	["mmol/l",	None,	None,	0.4,	0.6,	lambda sol: sol.tacc90],
    "Natrium":	["mg/l",	None,	None,	100,	150,	lambda sol: sol.total_element('Na') * 23e3],
    "Hardheid":	["mmol/l",	1,	1,	1.43,	2,	lambda sol: sol.total('Ca')*1e3 + sol.total('Mg')*1e3],
    "Ijzer":	["mg/l",	None,	None,	0.05,	0.1,	lambda sol: sol.total_element('Fe')*55.8e3],
    "Mangaan":	["mg/l",	None,	None,	0.01,	0.05,	lambda sol: sol.total_element('Mn')*54.9e3],
    "Aluminium":	["ug/l",	None,	None,	30,	30,	lambda sol: sol.total_element('Al')*27e6],
    "Antimoon":	["ug/l",	None,	None,	5,	5,	lambda sol: sol.total_element('Sb')*122e6],
    "Arseen":	["ug/l",	None,	None,	1,	10,	lambda sol: sol.total_element('As')*74.9e6],
    "Barium":	["ug/l",	None,	None,	100,	500,	lambda sol: sol.total_element('Ba')*137e6],
    "Boor":	["ug/l",	None,	None,	300,	500,	lambda sol: sol.total_element('B')*10.8e6],
    "Cadmium":	["ug/l",	None,	None,	1,	5,	lambda sol: sol.total_element('Cd')*112e6],
    "Chroom":	["ug/l",	None,	None,	10,	50,	lambda sol: sol.total_element('Cr')*52e6],
    "Koper":	["ug/l",	None,	None,	2000,	2000,	lambda sol: sol.total_element('Cu')*63.5e6],
    "Kwik":	["ug/l",	None,	None,	0.2,	0.5,	lambda sol: sol.total_element('Hg')*201e6],
    "Lood":	["ug/l",	None,	None,	10,	10,	lambda sol: sol.total_element('Pb')*207e6],
    "Nikkel":	["ug/l",	None,	None,	10,	20,	lambda sol: sol.total_element('Ni')*58.7e6],
    "Seleen":	["ug/l",	None,	None,	10,	10,	lambda sol: sol.total_element('Se')*79e6],
    "Zink":	["ug/l",	None,	None,	100,	100,	lambda sol: sol.total_element('Zn')*65.4e6]
}

