from setuptools import setup

setup(name='vitenstools',
      version='0.9.1',
      description='Vitens Specific Tools and Extensions for PhreeqPython',
      url='https://github.com/AbelHeinsbroek/vitens',
      author='Abel Heinsbroek',
      author_email='abel.heinsbroek@vitens.nl',
      license='Apache Licence 2.0',
      packages=['vitenstools'],
      zip_safe=False)
